@@ -59,8 +59,6 @@
       out <- filter(gt.env$tbl_score, .data$batch_c == in_batch_c & .data$batch_o == in_batch_o & .data$location == in_location)
     } else if (table == "data_doi") {
       out <- filter(gt.env$tbl_doi, .data$batch_c == in_batch_c & .data$batch_o == in_batch_o & .data$locations == in_locations)
-    } else if (table == "data_global") {
-      out <- filter(gt.env$tbl_global, .data$batch == in_batch_o)
     }
     out <- utils::head(out)
     out <- collect(out)
