@@ -9,14 +9,17 @@
 #' data in *data_object* that maps to this control batch is also removed.
 #' The dependency structure works as follows: *batch_keyword* / *batch_time* ->
 #' *data_control* -> *data_object* -> *data_score* -> *data_doi*.
+#'
 #' After using `remove_data`, run `vacuum_data` to free-up unused memory in
 #' the database file. Depending on the database size, `vacuum_data` might
 #' take some minutes for execution.
 #'
 #' @param table Database table from which the batch should be removed.  Object
 #' of type `character`.
+#'
 #' @param control Control batch for which the data is removed Object
 #' of type `numeric`.
+#'
 #' @param object Object batch for which the data is removed Object
 #' of type `numeric`.
 #'
@@ -49,7 +52,6 @@
 #' @importFrom DBI dbExecute
 #' @importFrom dplyr collect
 #' @importFrom dplyr filter
-#' @importFrom glue glue
 #' @importFrom rlang .data
 #' @rdname remove_data
 
@@ -87,12 +89,11 @@ remove_data <- function(table, control = NULL, object = NULL) {
       .remove_data_doi(batch_c = control, batch_o = object)
     }
   } else {
-    stop(glue("Error: 'table' must be either 'batch_keywords', 'batch_time', 'data_control', 'data_object', 'data_score', or 'data_doi'.\nYou provided {table}."))
+    stop(paste0("Error: 'table' must be either 'batch_keywords', 'batch_time', 'data_control', 'data_object', 'data_score', or 'data_doi'.\nYou provided ", table, "."))
   }
 }
 
 #' @export
-#' @importFrom DBI dbExecute
 #' @rdname remove_data
 
 vacuum_data <- function() {
@@ -114,7 +115,7 @@ vacuum_data <- function() {
     lst_export <- list(keywords_control, keywords_control)
     names(lst_export) <- list("keywords_control", "keywords_control")
     invisible(list2env(lst_export, envir = gt.env))
-    message(glue("Successfully deleted control batch {batch_c} from 'batch_keywords'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " from 'batch_keywords'."))
 
     .remove_data_control(batch_c = batch_c)
   } else if (type == "object") {
@@ -125,7 +126,7 @@ vacuum_data <- function() {
     lst_export <- list(keywords_object, keywords_object)
     names(lst_export) <- list("keywords_object", "keywords_object")
     invisible(list2env(lst_export, envir = gt.env))
-    message(glue("Successfully deleted object batch {batch_o} from 'batch_keywords'."))
+    message(paste0("Successfully deleted object batch ", batch_o, " from 'batch_keywords'."))
 
     .remove_data_object(batch_o = batch_o)
   }
@@ -147,7 +148,7 @@ vacuum_data <- function() {
     lst_export <- list(time_control, time_control)
     names(lst_export) <- list("time_control", "time_control")
     invisible(list2env(lst_export, envir = gt.env))
-    message(glue("Successfully deleted control batch {batch_c} from 'batch_time'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " from 'batch_time'."))
   } else if (type == "object") {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM batch_time WHERE type=? AND batch=?", params = list(type, batch_o))
     time_object <- filter(gt.env$tbl_time, .data$type == "object")
@@ -156,7 +157,7 @@ vacuum_data <- function() {
     lst_export <- list(time_object, time_object)
     names(lst_export) <- list("time_object", "time_object")
     invisible(list2env(lst_export, envir = gt.env))
-    message(glue("Successfully deleted object batch {batch_o} from 'batch_time'."))
+    message(paste0("Successfully deleted object batch ", batch_o, " from 'batch_time'."))
   }
 }
 
@@ -167,7 +168,7 @@ vacuum_data <- function() {
 .remove_data_control <- function(batch_c = NULL, batch_o = NULL) {
   walk(list(batch_c, batch_o), .check_batch)
   dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_control WHERE batch=?", params = list(batch_c))
-  message(glue("Successfully deleted control batch {batch_c} from 'data_control'."))
+  message(paste0("Successfully deleted control batch ", batch_c, " from 'data_control'."))
 
   .remove_data_object(batch_c = batch_c)
 }
@@ -180,13 +181,13 @@ vacuum_data <- function() {
   walk(list(batch_c, batch_o), .check_batch)
   if (is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_object WHERE batch_c=?", params = list(batch_c))
-    message(glue("Successfully deleted control batch {batch_c} from 'data_object'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " from 'data_object'."))
   } else if (is.null(batch_c) & !is.null(batch_o)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_object WHERE batch_o=?", params = list(batch_o))
-    message(glue("Successfully deleted object batch {batch_o} from 'data_object'."))
+    message(paste0("Successfully deleted object batch ", batch_o, " from 'data_object'."))
   } else if (!is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_object WHERE batch_o=? AND batch_c=?", params = list(batch_c, batch_o))
-    message(glue("Successfully deleted control batch {batch_c} and object batch {batch_o} from 'data_object'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " and object batch ", batch_o, " from 'data_object'."))
   }
 
   .remove_data_score(batch_c = batch_c, batch_o = batch_o)
@@ -200,13 +201,13 @@ vacuum_data <- function() {
   walk(list(batch_c, batch_o), .check_batch)
   if (is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_score WHERE batch_c=?", params = list(batch_c))
-    message(glue("Successfully deleted control batch {batch_c} from 'data_score'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " from 'data_score'."))
   } else if (is.null(batch_c) & !is.null(batch_o)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_score WHERE batch_o=?", params = list(batch_o))
-    message(glue("Successfully deleted object batch {batch_o} from 'data_score'."))
+    message(paste0("Successfully deleted object batch ", batch_o, " from 'data_score'."))
   } else if (!is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_score WHERE batch_o=? AND batch_c=?", params = list(batch_c, batch_o))
-    message(glue("Successfully deleted control batch {batch_c} and object batch {batch_o} from 'data_score'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " and object batch ", batch_o, " from 'data_score'."))
   }
 
   .remove_data_doi(batch_c = batch_c, batch_o = batch_o)
@@ -220,22 +221,12 @@ vacuum_data <- function() {
   walk(list(batch_c, batch_o), .check_batch)
   if (is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_doi WHERE batch_c=?", params = list(batch_c))
-    message(glue("Successfully deleted control batch {batch_c} from 'data_doi'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " from 'data_doi'."))
   } else if (is.null(batch_c) & !is.null(batch_o)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_doi WHERE batch_o=?", params = list(batch_o))
-    message(glue("Successfully deleted object batch {batch_o} from 'data_doi'."))
+    message(paste0("Successfully deleted object batch ", batch_o, " from 'data_doi'."))
   } else if (!is.null(batch_o) & !is.null(batch_c)) {
     dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_doi WHERE batch_o=? AND batch_c=?", params = list(batch_c, batch_o))
-    message(glue("Successfully deleted control batch {batch_c} and object batch {batch_o} from 'data_doi'."))
+    message(paste0("Successfully deleted control batch ", batch_c, " and object batch ", batch_o, " from 'data_doi'."))
   }
 }
-
-#' @title Remove from data_global
-#' @keywords internal
-#' @noRd
-
-.remove_data_global <- function(batch_c = NULL, batch_o = NULL) {
-  walk(list(batch_c, batch_o), .check_batch)
-  dbExecute(conn = gt.env$globaltrends_db, statement = "DELETE FROM data_global WHERE batch=?", params = list(batch_o))
-  message(glue("Successfully deleted object batch {batch_o} from 'data_global'."))
-}
