@@ -12,13 +12,13 @@ location_set <- c("US", "CN", "JP")
 
 # enter data -------------------------------------------------------------------
 data <- filter(example_control, batch == 1 & location %in% c(location_set[1:2], "world"))
-dbWriteTable(gt.env$globaltrends_db, "data_control", data, append = TRUE)
+dbAppendTable(gt.env$globaltrends_db, "data_control", data)
 data <- filter(example_object, batch_c == 1 & batch_o %in% 1:3 & location %in% c(location_set[1:2], "world"))
-dbWriteTable(gt.env$globaltrends_db, "data_object", data, append = TRUE)
+dbAppendTable(gt.env$globaltrends_db, "data_object", data)
 data <- filter(example_score, batch_c == 1 & batch_o %in% 1:3 & location %in% c(location_set[1:2], "world"))
-dbWriteTable(gt.env$globaltrends_db, "data_score", data, append = TRUE)
+dbAppendTable(gt.env$globaltrends_db, "data_score", data)
 data <- filter(example_doi, batch_c == 1 & batch_o %in% 1:3 & locations == "countries")
-dbWriteTable(gt.env$globaltrends_db, "data_doi", data, append = TRUE)
+dbAppendTable(gt.env$globaltrends_db, "data_doi", data)
 
 # export_control ---------------------------------------------------------------
 test_that("export_control1", {
